@@ -42,6 +42,11 @@ constexpr uint32_t MakeApiCallId(uint16_t family, uint16_t api_call)
     return ((static_cast<uint32_t>(family) << 16) & 0xffff0000) | (static_cast<uint32_t>(api_call) & 0x0000ffff);
 }
 
+constexpr uint16_t GetApiCallFamily(uint32_t call_id)
+{
+    return static_cast<uint16_t>((call_id >> 16) & 0x0000ffff);
+}
+
 enum ApiFamilyId : uint16_t
 {
     ApiFamily_None   = 0,
@@ -541,6 +546,12 @@ enum ApiCallId : uint32_t
     ApiCall_vkWaitForPresentKHR                                                                   = MakeApiCallId(ApiFamily_Vulkan, 0x1244),
     ApiCall_vkCmdBindInvocationMaskHUAWEI                                                         = MakeApiCallId(ApiFamily_Vulkan, 0x1245),
     ApiCall_vkGetMemoryRemoteAddressNV                                                            = MakeApiCallId(ApiFamily_Vulkan, 0x1246),
+    ApiCall_vkGetDeviceBufferMemoryRequirementsKHR                                                = MakeApiCallId(ApiFamily_Vulkan, 0x1247),
+    ApiCall_vkGetDeviceImageMemoryRequirementsKHR                                                 = MakeApiCallId(ApiFamily_Vulkan, 0x1248),
+    ApiCall_vkGetDeviceImageSparseMemoryRequirementsKHR                                           = MakeApiCallId(ApiFamily_Vulkan, 0x1249),
+    ApiCall_vkSetDeviceMemoryPriorityEXT                                                          = MakeApiCallId(ApiFamily_Vulkan, 0x124a),
+    ApiCall_vkCmdBeginRenderingKHR                                                                = MakeApiCallId(ApiFamily_Vulkan, 0x124b),
+    ApiCall_vkCmdEndRenderingKHR                                                                  = MakeApiCallId(ApiFamily_Vulkan, 0x124c),
 
     ApiCall_VulkanLast
     // clang-format on
